pub fn preferred_attainment<'a>(
candidates: &[&'a RegistryAttainment],
) -> Option<&'a RegistryAttainment>Expand description
The attainment sisu_attainment_id records: the course unit one when there is one, else the
latest.
pub fn preferred_attainment<'a>(
candidates: &[&'a RegistryAttainment],
) -> Option<&'a RegistryAttainment>The attainment sisu_attainment_id records: the course unit one when there is one, else the
latest.